;::::::::::::::::::::::::::::_____________________________________________::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
;::::::::::::::::::::::::::::MODELO BASADO EN AGENTES DE LA GENTRIFICACIÓN::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
;::::::::::::::::::::::::::::_____________________________________________::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::

extensions [ gis ]                  ;;Extensión que permitirá utilizar el mundo como un polígono.
globals [colonias ]                 ;;Variable global a la que tienen acceso los agentes y los patches

;************************************************************************************************************************************************
;************************************************************************************************************************************************
;;Se definen las razas
breed [habitantes habitante]
breed [comercios comercio]
breed [servicios servicio]
breed [educativos educativo]
breed [rycs ryc]                     ;;Contempla las amenidades culturales y de servicios


;************************************************************************************************************************************************
;************************************************************************************************************************************************
;Se definen las variables de estado
habitantes-own [ingreso gpe ]     ;;gpe = grado promedio de escolaridad
comercios-own  [categoría]
servicios-own  [categoría]                                                                                                 ;#cme = cantidad de comercios
educativos-own [categoría]                                                                                                 ;#ss = cantidad de servicios
rycs-own       [categoría]                                                                                                 ;#edu = cantidad de escuelas
patches-own    [nom_colonia código_postal precio_base precio2 tipo_vivienda #cme #ss #edu #ryc calidad1 calidad2]          ;#ryc = cantidad de recreativos y culturales

;***********************************************************************************************************************************************
;****************************************** SETUP **********************************************************************************************
;***********************************************************************************************************************************************

to setup            ;Comenzar
  clear-all         ;Limpiar el mundo
  setup-gis         ;Módulo para cargar, visualizar y concatenar la cartografía
  setup-amenidades  ;Módulo para sembrar las amenidades
  setup-patches     ;Módulo para caracterizar los patches
  setup-habitantes  ;Módulo para sembrar a los habitantes
  reset-ticks       ;Reiniciar los pasos del tiempo
end                 ;Finalizar el procedimiento


to setup-gis
  set colonias gis:load-dataset "PRECIOS_COLONIAS_09015.shp"   ;Instrucción para llamar el archivo shape
  gis:set-world-envelope (gis:envelope-of colonias)            ;Sincronizar el mundo con la cartografía
  gis:set-drawing-color 6                                      ;Contorno gris de la Delegación
  gis:draw  colonias 3                                         ;Grosor del contorno

  foreach gis:feature-list-of colonias                         ;Instrucciones para concatenar los nombres de las colonias
  [ask patches gis:intersecting ?
  [set nom_colonia gis:property-value ? "NOMBRE_2"]]
  foreach gis:feature-list-of colonias                         ;Instrucciones para concatenar el código postal
  [ask patches gis:intersecting ?
  [set código_postal gis:property-value ? "CP" ]]
  foreach gis:feature-list-of colonias                         ;Instrucciones para concatenar la variable de los precios
  [ask patches gis:intersecting ?
  [set precio_base  gis:property-value ? "DEP_2015" ]]
 end

to setup-amenidades
  create-comercios num_comercios                               ;La cantidad de los comercios se manipula con un deslizador
[set shape "dot"                                              ;Forma de punto
  set color 26                                                 ;Color anaranjado
  set size 1
  ;Las amenidades se distribuyen de acuerdo con la información del cuadro 3.4 del capítulo 3.
  ask n-of (round num_comercios * 0.0013) comercios [move-to one-of patches with [código_postal = 6880]]
  ask n-of (round num_comercios * 0.0032) comercios [move-to one-of patches with [código_postal = 6850]]
  ask n-of (round num_comercios * 0) comercios [move-to one-of patches with [código_postal = 6890]]
  ask n-of (round num_comercios * 0) comercios [move-to one-of patches with [código_postal = 6450]]
  ask n-of (round num_comercios * 0.0136) comercios [move-to one-of patches with [código_postal = 6350]]
  ask n-of (round num_comercios * 0) comercios [move-to one-of patches with [código_postal = 6780]]
  ask n-of (round num_comercios * 0.7424) comercios [move-to one-of patches with [código_postal = 6000]]
  ask n-of (round num_comercios * 0.0065) comercios [move-to one-of patches with [código_postal = 6140]]
  ask n-of (round num_comercios * 0.0058) comercios [move-to one-of patches with [código_postal = 6500]]
  ask n-of (round num_comercios * 0.0201) comercios [move-to one-of patches with [código_postal = 6720]]
  ask n-of (round num_comercios * 0) comercios [move-to one-of patches with [código_postal = 6840]]
  ask n-of (round num_comercios * 0.0032) comercios [move-to one-of patches with [código_postal = 6250]]
  ask n-of (round num_comercios * 0) comercios [move-to one-of patches with [código_postal = 6280]]
  ask n-of (round num_comercios * 0.0136) comercios [move-to one-of patches with [código_postal = 6300]]
  ask n-of (round num_comercios * 0.0097) comercios [move-to one-of patches with [código_postal = 6100]]
  ask n-of (round num_comercios * 0.0013) comercios [move-to one-of patches with [código_postal = 6170]]
  ask n-of (round num_comercios * 0.0291) comercios [move-to one-of patches with [código_postal = 6600]]
  ask n-of (round num_comercios * 0) comercios [move-to one-of patches with [código_postal = 6270]]
  ask n-of (round num_comercios * 0.0317) comercios [move-to one-of patches with [código_postal = 6200]]
  ask n-of (round num_comercios * 0.0065) comercios [move-to one-of patches with [código_postal = 6800]]
  ask n-of (round num_comercios * 0.0019) comercios [move-to one-of patches with [código_postal = 6870]]
  ask n-of (round num_comercios * 0.0149) comercios [move-to one-of patches with [código_postal = 6220]]
  ask n-of (round num_comercios * 0.0408) comercios [move-to one-of patches with [código_postal = 6700]]
  ask n-of (round num_comercios * 0.0155) comercios [move-to one-of patches with [código_postal = 6760]]
  ask n-of (round num_comercios * 0.0058) comercios [move-to one-of patches with [código_postal = 6470]]
  ask n-of (round num_comercios * 0.0013) comercios [move-to one-of patches with [código_postal = 6920]]
  ask n-of (round num_comercios * 0.0006) comercios [move-to one-of patches with [código_postal = 6430]]
  ask n-of (round num_comercios * 0.0181) comercios [move-to one-of patches with [código_postal = 6400]]
  ask n-of (round num_comercios * 0.0065) comercios [move-to one-of patches with [código_postal = 6030]]
  ask n-of (round num_comercios * 0.0019) comercios [move-to one-of patches with [código_postal = 6900]]
  ask n-of (round num_comercios * 0.0006) comercios [move-to one-of patches with [código_postal = 6820]]
  ask n-of (round num_comercios * 0.0006) comercios [move-to one-of patches with [código_postal = 6240]]
  ask n-of (round num_comercios * 0.0006) comercios [move-to one-of patches with [código_postal = 6860]]

  set categoría round random-float 3                       ;Se crean cuatro categorías de comercios.
  if categoría = 0 [set categoría "Supermercado"]
  if categoría = 1 [set categoría "Tienda departamental"]
  if categoría = 2 [set categoría "Joyería"]
  if categoría = 3 [set categoría "Naturista"]
]


  create-servicios num_servicios    ;Los servicios son controlados con undeslizador
[  set shape "dot"                   ;Forma de punto
  set color 76                      ;Color azul
  set size 1
  ask n-of (round num_servicios * 0.0041) servicios [move-to one-of patches with [código_postal = 6880]]
  ask n-of (round num_servicios * 0.0041) servicios [move-to one-of patches with [código_postal = 6850]]
  ask n-of (round num_servicios * 0.0020) servicios [move-to one-of patches with [código_postal = 6890]]
  ask n-of (round num_servicios * 0.0082) servicios [move-to one-of patches with [código_postal = 6450]]
  ask n-of (round num_servicios * 0.0225) servicios [move-to one-of patches with [código_postal = 6350]]
  ask n-of (round num_servicios * 0.0061) servicios [move-to one-of patches with [código_postal = 6780]]
  ask n-of (round num_servicios * 0.1824) servicios [move-to one-of patches with [código_postal = 6000]]
  ask n-of (round num_servicios * 0.0041) servicios [move-to one-of patches with [código_postal = 6140]]
  ask n-of (round num_servicios * 0.1270) servicios [move-to one-of patches with [código_postal = 6500]]
  ask n-of (round num_servicios * 0.0533) servicios [move-to one-of patches with [código_postal = 6720]]
  ask n-of (round num_servicios * 0) servicios [move-to one-of patches with [código_postal = 6840]]
  ask n-of (round num_servicios * 0.0020) servicios [move-to one-of patches with [código_postal = 6250]]
  ask n-of (round num_servicios * 0) servicios [move-to one-of patches with [código_postal = 6280]]
  ask n-of (round num_servicios * 0.0102) servicios [move-to one-of patches with [código_postal = 6300]]
  ask n-of (round num_servicios * 0.0205) servicios [move-to one-of patches with [código_postal = 6100]]
  ask n-of (round num_servicios * 0.0061) servicios [move-to one-of patches with [código_postal = 6170]]
  ask n-of (round num_servicios * 0.1824) servicios [move-to one-of patches with [código_postal = 6600]]
  ask n-of (round num_servicios * 0.0020) servicios [move-to one-of patches with [código_postal = 6270]]
  ask n-of (round num_servicios * 0.0123) servicios [move-to one-of patches with [código_postal = 6200]]
  ask n-of (round num_servicios * 0.0287) servicios [move-to one-of patches with [código_postal = 6800]]
  ask n-of (round num_servicios * 0) servicios [move-to one-of patches with [código_postal = 6870]]
  ask n-of (round num_servicios * 0.0041) servicios [move-to one-of patches with [código_postal = 6220]]
  ask n-of (round num_servicios * 0.1168) servicios [move-to one-of patches with [código_postal = 6700]]
  ask n-of (round num_servicios * 0.0492) servicios [move-to one-of patches with [código_postal = 6760]]
  ask n-of (round num_servicios * 0.0328) servicios [move-to one-of patches with [código_postal = 6470]]
  ask n-of (round num_servicios * 0.0041) servicios [move-to one-of patches with [código_postal = 6920]]
  ask n-of (round num_servicios * 0.0041) servicios [move-to one-of patches with [código_postal = 6430]]
  ask n-of (round num_servicios * 0.0307) servicios [move-to one-of patches with [código_postal = 6400]]
  ask n-of (round num_servicios * 0.0615) servicios [move-to one-of patches with [código_postal = 6030]]
  ask n-of (round num_servicios * 0.0061) servicios [move-to one-of patches with [código_postal = 6900]]
  ask n-of (round num_servicios * 0.0102) servicios [move-to one-of patches with [código_postal = 6820]]
  ask n-of (round num_servicios * 0.0020) servicios [move-to one-of patches with [código_postal = 6240]]
  ask n-of (round num_servicios * 0) servicios [move-to one-of patches with [código_postal = 6860]]
  set categoría round random-float 3       ;Se crean cuatro categorías de servicios.
  if categoría = 0 [set categoría "Banco"]
  if categoría = 1 [set categoría "Corporativo"]
  if categoría = 2 [set categoría "Hospital general"]
  if categoría = 3 [set categoría "Hotel"]
]


  create-educativos num_educativos         ;El número de escuelas es controlado con un deslizador
[ set shape "dot"                          ;Forma de punto
  set color 137                            ;Color rosa
  set size 1
  ask n-of (round num_educativos * 0.0093) educativos [move-to one-of patches with [código_postal = 6880]]
  ask n-of (round num_educativos * 0.0140) educativos [move-to one-of patches with [código_postal = 6850]]
  ask n-of (round num_educativos * 0.0016) educativos [move-to one-of patches with [código_postal = 6890]]
  ask n-of (round num_educativos * 0.0062) educativos [move-to one-of patches with [código_postal = 6450]]
  ask n-of (round num_educativos * 0.0047) educativos [move-to one-of patches with [código_postal = 6350]]
  ask n-of (round num_educativos * 0.0016) educativos [move-to one-of patches with [código_postal = 6780]]
  ask n-of (round num_educativos * 0.1322) educativos [move-to one-of patches with [código_postal = 6000]]
  ask n-of (round num_educativos * 0.0140) educativos [move-to one-of patches with [código_postal = 6140]]
  ask n-of (round num_educativos * 0.0280) educativos [move-to one-of patches with [código_postal = 6500]]
  ask n-of (round num_educativos * 0.0451) educativos [move-to one-of patches with [código_postal = 6720]]
  ask n-of (round num_educativos * 0) educativos [move-to one-of patches with [código_postal = 6840]]
  ask n-of (round num_educativos * 0.0062) educativos [move-to one-of patches with [código_postal = 6250]]
  ask n-of (round num_educativos * 0) educativos [move-to one-of patches with [código_postal = 6280]]
  ask n-of (round num_educativos * 0.0544) educativos [move-to one-of patches with [código_postal = 6300]]
  ask n-of (round num_educativos * 0.0295) educativos [move-to one-of patches with [código_postal = 6100]]
  ask n-of (round num_educativos * 0.0482) educativos [move-to one-of patches with [código_postal = 6170]]
  ask n-of (round num_educativos * 0.0684) educativos [move-to one-of patches with [código_postal = 6600]]
  ask n-of (round num_educativos * 0) educativos [move-to one-of patches with [código_postal = 6270]]
  ask n-of (round num_educativos * 0.0467) educativos [move-to one-of patches with [código_postal = 6200]]
  ask n-of (round num_educativos * 0.0311) educativos [move-to one-of patches with [código_postal = 6800]]
  ask n-of (round num_educativos * 0.0062) educativos [move-to one-of patches with [código_postal = 6870]]
  ask n-of (round num_educativos * 0.0342) educativos [move-to one-of patches with [código_postal = 6220]]
  ask n-of (round num_educativos * 0.1400) educativos [move-to one-of patches with [código_postal = 6700]]
  ask n-of (round num_educativos * 0.0575) educativos [move-to one-of patches with [código_postal = 6760]]
  ask n-of (round num_educativos * 0.0420) educativos [move-to one-of patches with [código_postal = 6470]]
  ask n-of (round num_educativos * 0.0078) educativos [move-to one-of patches with [código_postal = 6920]]
  ask n-of (round num_educativos * 0.0078) educativos [move-to one-of patches with [código_postal = 6430]]
  ask n-of (round num_educativos * 0.0793) educativos [move-to one-of patches with [código_postal = 6400]]
  ask n-of (round num_educativos * 0.0171) educativos [move-to one-of patches with [código_postal = 6030]]
  ask n-of (round num_educativos * 0.0420) educativos [move-to one-of patches with [código_postal = 6900]]
  ask n-of (round num_educativos * 0.0171) educativos [move-to one-of patches with [código_postal = 6820]]
  ask n-of (round num_educativos * 0.0016) educativos [move-to one-of patches with [código_postal = 6240]]
  ask n-of (round num_educativos * 0.0062) educativos [move-to one-of patches with [código_postal = 6860]]

  set categoría round random-float 1                ;Se crean dos categorías de escuelas
  if categoría = 0 [set categoría "Pública"]
  if categoría = 1 [set categoría "Privada"]
]


  create-rycs num_rycs              ;La cantidad de amenidades culturales y recreativas
                                    ;se controlan con un deslizador
[
  set shape "dot"                   ;Forma de punto
  set color 65                      ;Color verde
  set size 1
  ask n-of (round num_rycs * 0.0065) rycs [move-to one-of patches with [código_postal = 6880]]
  ask n-of (round num_rycs * 0.0033) rycs [move-to one-of patches with [código_postal = 6850]]
  ask n-of (round num_rycs * 0.0012) rycs [move-to one-of patches with [código_postal = 6890]]
  ask n-of (round num_rycs * 0.0015) rycs [move-to one-of patches with [código_postal = 6450]]
  ask n-of (round num_rycs * 0.0175) rycs [move-to one-of patches with [código_postal = 6350]]
  ask n-of (round num_rycs * 0.0018) rycs [move-to one-of patches with [código_postal = 6780]]
  ask n-of (round num_rycs * 0.2401) rycs [move-to one-of patches with [código_postal = 6000]]
  ask n-of (round num_rycs * 0.0276) rycs [move-to one-of patches with [código_postal = 6140]]
  ask n-of (round num_rycs * 0.0523) rycs [move-to one-of patches with [código_postal = 6500]]
  ask n-of (round num_rycs * 0.0612) rycs [move-to one-of patches with [código_postal = 6720]]
  ask n-of (round num_rycs * 0) rycs [move-to one-of patches with [código_postal = 6840]]
  ask n-of (round num_rycs * 0.0030) rycs [move-to one-of patches with [código_postal = 6250]]
  ask n-of (round num_rycs * 0) rycs [move-to one-of patches with [código_postal = 6280]]
  ask n-of (round num_rycs * 0.0484) rycs [move-to one-of patches with [código_postal = 6300]]
  ask n-of (round num_rycs * 0.0377) rycs [move-to one-of patches with [código_postal = 6100]]
  ask n-of (round num_rycs * 0.0345) rycs [move-to one-of patches with [código_postal = 6170]]
  ask n-of (round num_rycs * 0.0960) rycs [move-to one-of patches with [código_postal = 6600]]
  ask n-of (round num_rycs * 0.0006) rycs [move-to one-of patches with [código_postal = 6270]]
  ask n-of (round num_rycs * 0.0238) rycs [move-to one-of patches with [código_postal = 6200]]
  ask n-of (round num_rycs * 0.0279) rycs [move-to one-of patches with [código_postal = 6800]]
  ask n-of (round num_rycs * 0.0009) rycs [move-to one-of patches with [código_postal = 6870]]
  ask n-of (round num_rycs * 0.0202) rycs [move-to one-of patches with [código_postal = 6220]]
  ask n-of (round num_rycs * 0.1174) rycs [move-to one-of patches with [código_postal = 6700]]
  ask n-of (round num_rycs * 0.0389) rycs [move-to one-of patches with [código_postal = 6760]]
  ask n-of (round num_rycs * 0.0315) rycs [move-to one-of patches with [código_postal = 6470]]
  ask n-of (round num_rycs * 0.0018) rycs [move-to one-of patches with [código_postal = 6920]]
  ask n-of (round num_rycs * 0.0024) rycs [move-to one-of patches with [código_postal = 6430]]
  ask n-of (round num_rycs * 0.0437) rycs [move-to one-of patches with [código_postal = 6400]]
  ask n-of (round num_rycs * 0.0309) rycs [move-to one-of patches with [código_postal = 6030]]
  ask n-of (round num_rycs * 0.0083) rycs [move-to one-of patches with [código_postal = 6900]]
  ask n-of (round num_rycs * 0.0125) rycs [move-to one-of patches with [código_postal = 6820]]
  ask n-of (round num_rycs * 0.0018) rycs [move-to one-of patches with [código_postal = 6240]]
  ask n-of (round num_rycs * 0.0048) rycs [move-to one-of patches with [código_postal = 6860]]

  set categoría round random-float 1            ;Se crean dos categorías de rycs.
  if categoría = 0 [set categoría "Recreativo"]
  if categoría = 1 [set categoría "Cultural"]
]
end

to setup-patches
  ask patches with [código_postal != 0]                  ;Instrucciones para calcular amenidades en el radio
  [set #cme count comercios-on patches in-radius radio   ;cuya dimensión es controlada con el deslizador
   set #ss count servicios-on patches in-radius radio
   set #edu count educativos-on patches in-radius radio
   set #ryc count rycs-on patches in-radius radio

   set calidad1 1   ;Instrucciones para que recalcule la calidad de los patches
   if #cme >= 1 and #cme <= 767 [set calidad1 calidad1 + ((precio_base / 1000000) * #cme)]
   if #ss >= 1 and #ss <= 668 [set calidad1 calidad1 + ((precio_base / 1000000) * #ss)]
   if #edu >= 1 and #edu <= 573 [set calidad1 calidad1 + ((precio_base / 1000000) * #edu)]
   if #ryc >= 1 and #ryc <= 544 [set calidad1 calidad1 + ((precio_base / 1000000) * #ryc)]


  set tipo_vivienda round random-float 3      ;Se categorizan 5 tipos de vivienda.
  if tipo_vivienda = 0 [set tipo_vivienda "Económica"]
  if tipo_vivienda = 1 [set tipo_vivienda "Interés-social"]
  if tipo_vivienda = 2 [set tipo_vivienda "Medio"]
  if tipo_vivienda = 3 [set tipo_vivienda "Residencial"]
  if tipo_vivienda = 4 [set tipo_vivienda "Residencial-plus"]

  ;Los tipos de vivienda se vinculan con un rango de precios.
  if precio_base > 400000 and precio_base < 600000 [set tipo_vivienda "Económica"]
  if precio_base > 600001 and precio_base < 800000 [set tipo_vivienda "Interés-social"]
  if precio_base > 800001 and precio_base < 1000000 [set tipo_vivienda "Medio"]
  if precio_base > 1000001 and precio_base < 2000000 [set tipo_vivienda "Residencial"]
  if precio_base > 2000001 [set tipo_vivienda "Residencial-plus"]

  ]

end

to setup-habitantes
  create-habitantes num_habitantes    ;La cantidad de habitantes son controladas con un deslizador.
ask habitantes
[ set shape "person"                  ;Forma de persona
  set color 8                         ;Color gris
  set size 1

  set gpe round random-float 3        ;Se crean 4 categorías de gpe
  if gpe = 0 [set gpe "Sin-escolaridad"]
  if gpe = 1 [set gpe "Básica"]
  if gpe = 2 [set gpe "Media-Superior"]
  if gpe = 3 [set gpe "Superior"]

  set ingreso abs round random-normal 5000 2780    ;Los gpe se vinculan con rangos de ingreso.
  if ingreso > 0 and ingreso <= 1000 [set gpe "Sin-escolaridad"]
  if ingreso >= 1001 and ingreso <= 4000 [set gpe "Básica"]
  if ingreso >= 4001 and ingreso <= 6000 [set gpe "Media-superior"]
  if ingreso > 6001 [set gpe "Superior"]
]
end

;***********************************************************************************************************************************************
;****************************************** GO *************************************************************************************************
;***********************************************************************************************************************************************
to go                          ;Botón "Ejecutar"
ubicación-gentrificadores1     ;Módulo para las reglas de trancisión de los gentrificadores tipo 1.
ubicación-gentrificadores2     ;Módulo para las reglas de trancisión de los gentrificadores tipo 2.
ubicación-no-gentrificadores   ;Módulo para las reglas de trancisión de los no gentrificadores.
tick                           ;Contabilizar los pasos del tiempo.
end

to ubicación-gentrificadores1
ask habitantes with [ingreso > 6000]     ;Los habitantes con Y > 6000 se ubican en los patches con P>1,000,000 y al menos una de cada amenidad en el radio
[move-to one-of patches with [
    ((precio_base >= 1000000) and (#cme > 1)) and
    ((precio_base >= 1000000) and (#ss > 1)) and
    ((precio_base >= 1000000) and (#edu > 1)) and
    ((precio_base >= 1000000) and (#ryc > 1))]
set pcolor scale-color sky calidad2 1 200]   ;Instrucción para que los patches se coloreen de acuerdo a una rampa de color
incrementar_precio incrementar_calidad       ;Módulos para incrementar la calidad y el precio de los patches
end

to ubicación-gentrificadores2             ;Los habitantes con  4000 < Y < 5999 se ubican en los patches con 700000 < P < 1,000,000 y al menos una de cada amenidad en el radio
ask habitantes with [(ingreso < 5999) and (ingreso > 4000)]
[move-to one-of patches with [
    (((precio_base >= 700000) and (precio_base <= 999999)) and (#cme > 1)) and
    (((precio_base >= 700000) and (precio_base <= 999999)) and (#ss > 1)) and
    (((precio_base >= 700000) and (precio_base <= 999999)) and (#edu > 1)) and
    (((precio_base >= 700000) and (precio_base <= 999999)) and (#ryc > 1))]
set pcolor scale-color sky calidad2 1 200 ]  ;Instrucción para que los patches se coloreen de acuerdo a una rampa de color
incrementar_precio incrementar_calidad       ;Módulos para incrementar la calidad y el precio de los patches
end

to ubicación-no-gentrificadores            ;Los habitantes con  Y < 3999  se ubican en los patches con P>1,000,000 y al menos una de cada amenidad en el radio
ask habitantes with [(ingreso < 3999)]
[move-to one-of patches with [(precio_base <= 699999) and (precio_base > 200000)]
set pcolor scale-color sky calidad2 1 200]   ;Instrucción para que los patches se coloreen de acuerdo a una rampa de color
disminuir_precio disminuir_calidad           ;Módulos para disminuir la calidad y el precio de los patches
end

to incrementar_calidad                       ;Instrucciones para incrementar la calidad
ask patches  [set calidad2 calidad1 + (calidad1 * 0.23)]
end

to incrementar_precio                        ;Instrucciones para elevar el precio
ask patches [set precio2 precio_base + (precio_base * 0.24)]
end

to disminuir_calidad                          ;Instrucciones para disminuir la calidad
ask patches [set calidad2 calidad1 - (calidad1 * 0.22)]
end

to disminuir_precio                           ;Instrucciones para disminuir el precio
ask patches [set precio2 precio_base - (precio_base * 0.25)]
end

;***********************************************************************************************************************************************
;****************************************** PLOTS **********************************************************************************************
;***********************************************************************************************************************************************

;Instrucciones para graficar los resultados de la simulación
;Gráfica 1
to-report Gentrificadores1
report count habitantes-on patches with [precio2 > 800000]
end

to-report Gentrificadores2
report count habitantes-on patches with [(precio2 <= 799999) and (precio2 > 500000)]
end

to-report No-gentrificadores
report count habitantes-on patches with [(precio2 < 499999) and (precio2 > 200000)]
end

;Gráfica 2
to-report Calidad
report mean [calidad2] of patches
end

to-report Precio
report mean [(precio2 / 10000)] of patches with [código_postal != 0 ]
end
@#$#@#$#@
GRAPHICS-WINDOW
244
10
864
651
30
30
10.0
1
10
1
1
1
0
0
0
1
-30
30
-30
30
0
0
1
Pasos del tiempo
30.0

BUTTON
20
82
83
115
Inicio
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
19
129
191
162
num_comercios
num_comercios
1
1067
655
1
1
NIL
HORIZONTAL

SLIDER
19
169
191
202
num_servicios
num_servicios
1
968
596
1
1
NIL
HORIZONTAL

SLIDER
17
210
189
243
num_educativos
num_educativos
1
873
555
1
1
NIL
HORIZONTAL

SLIDER
17
251
189
284
num_rycs
num_rycs
1
844
544
1
1
NIL
HORIZONTAL

SLIDER
15
309
187
342
Radio
Radio
0
10
4
1
1
NIL
HORIZONTAL

SLIDER
14
369
186
402
num_habitantes
num_habitantes
1
2000
1771
1
1
NIL
HORIZONTAL

MONITOR
9
422
106
467
% Sin escolaridad
((count habitantes with [gpe = \"Sin-escolaridad\"]) / count habitantes) * 100
2
1
11

MONITOR
131
422
210
467
% E. Básica
((count habitantes with [gpe = \"Básica\"]) / count habitantes ) * 100
2
1
11

MONITOR
10
472
117
517
% E. Media Superior
((count habitantes with [gpe = \"Media-superior\"]) / count habitantes ) * 100
2
1
11

MONITOR
130
471
211
516
% E. Superior
((count habitantes with [gpe = \"Superior\"]) / count habitantes ) * 100
2
1
11

BUTTON
104
81
182
114
Ejecutar
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
873
49
1306
254
Gentrificación
Tiempo
Unidades territoriales
0.0
20.0
0.0
20.0
true
true
"" ""
PENS
"Gentrificadores 1" 1.0 0 -955883 true "" "plot Gentrificadores1"
"Gentrificadores 2" 1.0 0 -13840069 true "" "plot Gentrificadores2"
"Trabajadores promedio" 1.0 0 -14070903 true "" "plot No-gentrificadores"

PLOT
870
277
1305
512
Características territoriales
Tiempo
Cantidad
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"Calidad" 1.0 0 -2674135 true "" "plot Calidad"
"Precio" 1.0 0 -14835848 true "" "plot Precio"

TEXTBOX
8
11
226
83
Ejecute el botón \"Inicio\" con una velocidad máxima para que se carguen rápidamente las condiciones iniciales. Una vez hecho, regrese a la velocidad normal.
11
104.0
1

@#$#@#$#@
## ¿Qué es?

Pregunta de investigación: ¿La interacción de personas de clase alta y clase baja en un entorno urbano con características de las ciudades centrales dan lugar a un proceso de gentrificación?

Este es un Modelo Basado en Agentes que tiene como propósito simular la dinámica residencial, económica y social para identificar la gentrificación en la Delegación Cuauhtémoc, bajo los supuestos de la perspectiva crítica del proceso que se muestran a continuación y que son discutidos ampliamente en el capítulo 1:

-Es un fenómeno que se lleva a cabo en las ciudades centrales, ya que concentran diversas actividades económicas, principalmente las del sector de los servicios, que corresponden al perfil que genera la gentrificación. (Smith, 1996)
-Las inversiones de la esfera pública y privada transforman los barrios proletarios, ya que el Estado acondiciona esos espacios para atraer a los empresarios la oportunidad de acumular y valorizar el capital. (Smith, 1996)
-La gentrificación también se explica por el lado del consumo, en cuanto a que los nuevos residentes tienen un perfil de clase alta donde sus gustos y preferencias son más "refinadas". En función de ello, los inversionistas estarán interesados en satisfacer esa demanda poniendo en marcha negocios acordes a ese perfil. (Shaw, 2008)
-Se impulsa el mercado inmobiliario, como efecto el precio de las viviendas y de los terrenos aumentan. Al mismo tiempo, surgen tipologías diversas acordes al perfil urbano. (Ha, 2004)
-El encarecimiento de las zonas gentrificadas conduce al desplazamiento progresivo hacia la periferia de la población trabajadora promedio. (Smith, 1996)

##Descripción del mundo

El mundo no es toroidal, es decir que los límites horizontales no se comunican entre sí ni los verticales, esto es así porque los patches son representaciones de la geografía real que en conjunto configuran al espacio como un SIG caracterizado como las colonias de la Delegación Cuauhtémoc de la Ciudad de México.

##Descripción de los agentes y de los patches

En el modelo existen cuatro tipos de agentes: los habitantes, las unidades económicas de comercio y servicios, y las amenidades culturales y recreativas. A cada uno se le asignan características que en la literatura de los ABM se conocen como variables de estado.

Agentes:
Habitantes: Ingreso, grado promedio de escolaridad
Unidades económicas: comercios y servicios
Amenidades: culturales y recreativas

Patches:
Precio de los departamentos en 2015
Calidad


## ¿Cómo trabaja?
Inicialización:
 *Botón "Comenzar": Primero carga, visualiza la cartografía y concatena los patches    con       la información del polígono de la Delegación Cuauhtémoc y después genera los agentes      distribuyéndolos aleatoriamente dentro de él, sujetos a una razón de proporcionalidad     descrita en el cuadro 3.4 del capítulo 3.

Procedimiento:
El modelo se pone en marcha al accionar el botón "Ejecutar", bajo el supuesto de que un paso del tiempo es equivalente a un trimestre:

*PRIMERA REGLA DE TRANSICIÓN: Elección de residencia de los gentrificadores tipo 1: Los residentes cuyo ingreso es superior a los $6,000 mensuales, con previa evaluación, se mueven hacia los patches cuyo valor sea superior a $1,000,000 sin discriminar la tipología, bajo la restricción de que en el radio de influencia deben haber por lo menos una amenidad cultural, un establecimiento comercial, una amenidad recreativa y una escuela.
Al llegar el habitante a la vivienda que cumple con esas características se queda, como señal de esto el patche. Si no le agrada la vivienda, sigue buscando. En la gráfica "Gentrificación" se identifica en color naranja el número de patches gentrificados. Como resultado de que los agentes gentrificadores ubicaron dónde residir, el precio de la vivienda se recalcula como lo indica la teoría, en este caso aumenta su valor en un 24%, y también aumenta su calidad en 22% mostrándose el nuevo valor en la variable de estado "precio2" y "calidad2" respectivamente.

*SEGUNDA REGLA DE TRANCISIÓN: Elección de residencia de los gentrificadores tipo 2:
Los residentes con un ingreso superior a los $4,000 pero inferior a $6,000 inician su trayectoria evaluando el valor de los departamentos y su entorno. Deciden quedarse en un departamento si su precio es superior a $700,000 pero inferior a un millón y si además tienen alrededor al menos una amenidad de cada categoría.Como resultado de la habitabilidad, el precio incrementa en 24% y la calidad en 22%.

*TERCERA REGLA DE TRASICIÓN: Elección de residencia de los no gentrificadores:
Se asume que los agentes no gentrificadores tinen un ingreso menor a $4,000, por lo que buscarán ubicarse en una vivienda barata donde preferentemente no hayan amenidades que puedan encarecer el valor de los predios. Al decidir quedarse,el precio de los terrenos disminuye en 23% y la calidad en 21%.

*ESCALA DE COLOR: En cada ejecución los patches asumen un color en función de una rampa de color, donde los colores más brillantes aluden a valores altos y los más oscuros a valores bajos.


## ¿Cómo usarlo?

Se recomienda que al sembrar las condiciones iniciales, la velocidad esté en máxima.

Botón Comenzar: Carga la cartografía y concatena su información con los patches, enseguida siembra y distribuye los agentes aleatoriamente dentro del polígono.

Botón Ejecutar: Ejecuta los procedimientos de las reglas de transición.

Deslizadores: Con ellos se controla la cantidad de agentes que actuarán en la simulación.
Monitores: Muestra el porcentaje de agentes categorizados por gpe.

Gráfica "Gentrificación": Muestra los resultados de la ejecución de los procecimientos.

Gráfica "Características territoriales": Muestra el promedio de la actualización de las calidades y los precios de los predios.

## Aspectos a notar

*Resultados de las gráficas "Gentrificación": Sin importar el escenario, el comportamiento gráfico de los tres tipos de habitantes se mantiene en la misma posición, aunque la distinción es la volatilidad en las trayectorias.

*Forma de la gráficas: Se observa que en pocos pasos de tiempo las tres reglas de transición llegan a una cierta estabilidad, no del todo, esto es así porque a medida que avanza la simulación a los habitantes les queda poco espacio para gentrificar.


## Sugerencias a intentar

Se recomienda que el usuario interactúe con los deslizadores, algunos intentos pueden verse en la sección del analizador de comportamiento.

## Sugerencias para hacer más complejo el modelo o extenderlo

El usuario puede cambiar el tamaño del radio de influencia para ver cómo se comportan los residentes si es más pequeño o más grande.
También puede agregar como variable de estado la edad de los habitantes para visualizar cómo se lleva a cabo el proceso de gentrificación al tomar en cuenta grupos como los jóvenes, ancianos, etcétera.



## Modelos relacionados
El usuario puede ver otro modelo de gentrificación en el siguiente enlace:
http://ccl.northwestern.edu/netlogo/models/community/residential%20mobility%20as%20a%20result%20of%20gentrification

Así como también se recomienda examinar el modelo "Urban Suite", "Slime" y "Ticket sales" localizado en la biblioteca de modelos cuyos algunas instrucciones me guiaron en la realización de este modelo.

## Bibliografía

[1] ATKINSON, R. (2004). “The evidence on the impact of Gentrification:New Lessons for the urban renaissance?”, en: European Journal if Housing Policy, Vol. 3, N° 1, pp. 107-131

[2] FOREST, B., JACKSON, J. y SENGUPTA, R. (2008) “Agent-Based Simulation of Urban Residential Dynamics and Land Rent Change in a Gentrifying Area of Boston” in: Transactions in GIS, No. 12, pp. 475-491

[3] HA, S. (2004) “Housing Renewal and neighborhood change as a gentrification process in Seoul” in: Cities, Vol. 21, N° 5, pp. 381-389

[4] JORDAN, R. et. al. (2012) "Agent-Based Modelling of Residential Mobility, Housing choice and regeneration" in: Agent-Based Models of Geographical Systems, pp. 511-524

[5] NARA, A. y TORRENS, P. (2006) “Innercity gentrification simulation using hybrid models of Cellular Automata and Multi-Agent Systems”, UTAH

[6] SHAW, K. (2008) “Gentrification: What it is, why it is and what can be about it” en: Journal Compilation, Vol. 2, No. 5, pp, 1697-1728

[7] SMITH, N. (1996). “La Nueva Frontera Urbana: Ciudad Revanchista y Gentrificación”, Routledge, London, 378 p

[8] WILENSKY, U. y RAND, W. (2015) “An introduction to Agent-Bsed Modelling: Modeling natural, social and engineered complex systems with NetLogo” Massachusetts Institute of Technology, 482 p.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

building store
false
0
Rectangle -7500403 true true 30 45 45 240
Rectangle -16777216 false false 30 45 45 165
Rectangle -7500403 true true 15 165 285 255
Rectangle -16777216 true false 120 195 180 255
Line -7500403 true 150 195 150 255
Rectangle -16777216 true false 30 180 105 240
Rectangle -16777216 true false 195 180 270 240
Line -16777216 false 0 165 300 165
Polygon -7500403 true true 0 165 45 135 60 90 240 90 255 135 300 165
Rectangle -7500403 true true 0 0 75 45
Rectangle -16777216 false false 0 0 75 45

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

person business
false
0
Rectangle -1 true false 120 90 180 180
Polygon -13345367 true false 135 90 150 105 135 180 150 195 165 180 150 105 165 90
Polygon -7500403 true true 120 90 105 90 60 195 90 210 116 154 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 183 153 210 210 240 195 195 90 180 90 150 165
Circle -7500403 true true 110 5 80
Rectangle -7500403 true true 127 76 172 91
Line -16777216 false 172 90 161 94
Line -16777216 false 128 90 139 94
Polygon -13345367 true false 195 225 195 300 270 270 270 195
Rectangle -13791810 true false 180 225 195 300
Polygon -14835848 true false 180 226 195 226 270 196 255 196
Polygon -13345367 true false 209 202 209 216 244 202 243 188
Line -16777216 false 180 90 150 165
Line -16777216 false 120 90 150 165

person construction
false
0
Rectangle -7500403 true true 123 76 176 95
Polygon -1 true false 105 90 60 195 90 210 115 162 184 163 210 210 240 195 195 90
Polygon -13345367 true false 180 195 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285
Circle -7500403 true true 110 5 80
Line -16777216 false 148 143 150 196
Rectangle -16777216 true false 116 186 182 198
Circle -1 true false 152 143 9
Circle -1 true false 152 166 9
Rectangle -16777216 true false 179 164 183 186
Polygon -955883 true false 180 90 195 90 195 165 195 195 150 195 150 120 180 90
Polygon -955883 true false 120 90 105 90 105 165 105 195 150 195 150 120 120 90
Rectangle -16777216 true false 135 114 150 120
Rectangle -16777216 true false 135 144 150 150
Rectangle -16777216 true false 135 174 150 180
Polygon -955883 true false 105 42 111 16 128 2 149 0 178 6 190 18 192 28 220 29 216 34 201 39 167 35
Polygon -6459832 true false 54 253 54 238 219 73 227 78
Polygon -16777216 true false 15 285 15 255 30 225 45 225 75 255 75 270 45 285

person graduate
false
0
Circle -16777216 false false 39 183 20
Polygon -1 true false 50 203 85 213 118 227 119 207 89 204 52 185
Circle -7500403 true true 110 5 80
Rectangle -7500403 true true 127 79 172 94
Polygon -8630108 true false 90 19 150 37 210 19 195 4 105 4
Polygon -8630108 true false 120 90 105 90 60 195 90 210 120 165 90 285 105 300 195 300 210 285 180 165 210 210 240 195 195 90
Polygon -1184463 true false 135 90 120 90 150 135 180 90 165 90 150 105
Line -2674135 false 195 90 150 135
Line -2674135 false 105 90 150 135
Polygon -1 true false 135 90 150 105 165 90
Circle -1 true false 104 205 20
Circle -1 true false 41 184 20
Circle -16777216 false false 106 206 18
Line -2674135 false 208 22 208 57

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.3.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="Experimento_Base" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="65"/>
    <metric>Gentrificadores1</metric>
    <metric>Gentrificadores2</metric>
    <metric>No-gentrificadores</metric>
    <enumeratedValueSet variable="num_educativos">
      <value value="555"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num_comercios">
      <value value="655"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Radio">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num_servicios">
      <value value="596"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num_rycs">
      <value value="544"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num_habitantes">
      <value value="1771"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experimento1" repetitions="15" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="75"/>
    <metric>Gentrificadores1</metric>
    <metric>Gentrificadores2</metric>
    <metric>No-gentrificadores</metric>
    <enumeratedValueSet variable="num_educativos">
      <value value="555"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num_comercios">
      <value value="655"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Radio">
      <value value="2"/>
      <value value="5"/>
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num_servicios">
      <value value="596"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num_rycs">
      <value value="544"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num_habitantes">
      <value value="1771"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experimento2" repetitions="15" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="75"/>
    <metric>Gentrificadores1</metric>
    <metric>Gentrificadores2</metric>
    <metric>No-gentrificadores</metric>
    <enumeratedValueSet variable="num_educativos">
      <value value="250"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num_comercios">
      <value value="250"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Radio">
      <value value="4"/>
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num_servicios">
      <value value="250"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num_rycs">
      <value value="250"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num_habitantes">
      <value value="500"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment3" repetitions="15" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="75"/>
    <metric>Gentrificadores1</metric>
    <metric>Gentrificadores2</metric>
    <metric>No-gentrificadores</metric>
    <enumeratedValueSet variable="num_educativos">
      <value value="250"/>
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num_comercios">
      <value value="250"/>
      <value value="700"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Radio">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num_servicios">
      <value value="300"/>
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num_rycs">
      <value value="250"/>
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num_habitantes">
      <value value="300"/>
      <value value="800"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment5" repetitions="15" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="65"/>
    <metric>Gentrificadores1</metric>
    <metric>Gentrificadores2</metric>
    <metric>No-gentrificadores</metric>
    <enumeratedValueSet variable="num_educativos">
      <value value="751"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Radio">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num_servicios">
      <value value="401"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num_habitantes">
      <value value="778"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num_comercios">
      <value value="918"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num_rycs">
      <value value="366"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
